==> letodms_3.3.11+dfsg.orig.tar.gz: letodms-3.3.11+dfsg/out/out.UserList.php <==
<?php
//    MyDMS. Document Management System
//    Copyright (C) 2010 Matteo Lucarelli
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

include("../inc/inc.Settings.php");
include("../inc/inc.DBInit.php");
include("../inc/inc.Language.php");
include("../inc/inc.ClassUI.php");
include("../inc/inc.Authentication.php");

if (!$user->isAdmin()) {
	UI::exitError(getMLText("admin_tools"),getMLText("access_denied"));
}

UI::htmlStartPage(getMLText("admin_tools"));
UI::globalNavigation();
UI::pageNavigation(getMLText("admin_tools"), "admin_tools");
UI::contentHeading(getMLText("user_list"));
UI::contentContainerStart();

$users = getAllUsers();
for ($i = 0; $i < count($users); $i++) {
	$currUser = $users[$i];
	if ($currUser->isGuest())
		continue;

	UI::contentSubHeading(getMLText("user") . ": \"" . $currUser->getFullName() . "\"");
?>
	<table border="0">
		<tr>
			<td><?php printMLText("user_login");?>:</td>
			<td><?php print $currUser->getLogin();?></td>
		</tr>
	<tr>
			<td><?php printMLText("user_name");?>:</td>
			<td><?php print $currUser->getFullName();?></td>
		</tr>
		<tr>
			<td><?php printMLText("email");?>:</td>
			<td><a href="mailto:<?php print $currUser->getEmail();?>"><?php print $currUser->getEmail();?></a></td>
		</tr>
		<tr>
			<td><?php printMLText("comment");?>:</td>
			<td><?php print $currUser->getComment();?></td>
		</tr>
		<tr>
			<td><?php printMLText("groups");?>:</td>
			<td>
				<?php
					$groups = $currUser->getGroups();
					if (count($groups) == 0) {
						printMLText("no_groups");
					}
					else {
						for ($j = 0; $j < count($groups); $j++)	{
							print $groups[$j]->getName();
							if ($j +1 < count($groups))
								print ", ";
						}
					}
				?>
			</td>
		</tr>
		<tr>
			<td><?php printMLText("user_image");?>:</td>
			<td>
				<?php
					if ($currUser->hasImage())
						print "<img src=\"".$settings->_httpRoot . "out/out.UserImage.php?userid=".$currUser->getId()."\">";
					else
						printMLText("no_user_image");
				?>
			</td>
		</tr>
	</table>
<?php
}

UI::contentContainerEnd();
UI::htmlEndPage();
?>

==> letodms_3.4.2+dfsg.orig.tar.gz: letodms-3.4.2+dfsg/out/out.UserList.php <==
<?php
//    MyDMS. Document Management System
//    Copyright (C) 2010 Matteo Lucarelli
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

include("../inc/inc.Settings.php");
include("../inc/inc.DBInit.php");
include("../inc/inc.Language.php");
include("../inc/inc.ClassUI.php");
include("../inc/inc.Authentication.php");

if (!$user->isAdmin()) {
	UI::exitError(getMLText("admin_tools"),getMLText("access_denied"));
}

UI::htmlStartPage(getMLText("admin_tools"));
UI::globalNavigation();
UI::pageNavigation(getMLText("admin_tools"), "admin_tools");
UI::contentHeading(getMLText("user_list"));
UI::contentContainerStart();

$users = $dms->getAllUsers($settings->_sortUsersInList);
foreach ($users as $currUser) {
	if ($currUser->isGuest())
		continue;

	UI::contentSubHeading(getMLText("user") . ": \"" . $currUser->getFullName() . "\"");
?>
	<table border="0">
		<tr>
			<td><?php printMLText("user_login");?>:</td>
			<td><?php print $currUser->getLogin();?></td>
		</tr>
	<tr>
			<td><?php printMLText("user_name");?>:</td>
			<td><?php print $currUser->getFullName();?></td>
		</tr>
		<tr>
			<td><?php printMLText("email");?>:</td>
			<td><a href="mailto:<?php print $currUser->getEmail();?>"><?php print $currUser->getEmail();?></a></td>
		</tr>
		<tr>
			<td><?php printMLText("comment");?>:</td>
			<td><?php print $currUser->getComment();?></td>
		</tr>
		<tr>
			<td><?php printMLText("groups");?>:</td>
			<td>
				<?php
					$groups = $currUser->getGroups();
					if (count($groups) == 0) {
						printMLText("no_groups");
					}
					else {
						for ($j = 0; $j < count($groups); $j++)	{
							print $groups[$j]->getName();
							if ($j +1 < count($groups))
								print ", ";
						}
					}
				?>
			</td>
		</tr>
		<tr>
			<td><?php printMLText("user_image");?>:</td>
			<td>
				<?php
					if ($currUser->hasImage())
						print "<img src=\"".$settings->_httpRoot . "out/out.UserImage.php?userid=".$currUser->getId()."\">";
					else
						printMLText("no_user_image");
				?>
			</td>
		</tr>
	</table>
<?php
}

UI::contentContainerEnd();
UI::htmlEndPage();
?>
